==> velocity_x-3.1.1.tar.gz: lib/velocity_x.dart <==
library velocity_x;

export 'package:animator/animator.dart';
export 'package:vxstate/vxstate.dart';

export 'src/dart/guard.dart';
export 'src/dart/timeline.dart';
export 'src/extensions/bool_ext.dart';
export 'src/extensions/context_ext.dart';
export 'src/extensions/date_time_ext.dart';
export 'src/extensions/iterable_ext.dart';
export 'src/extensions/list_ext.dart';
export 'src/extensions/num_ext.dart';
export 'src/extensions/string_ext.dart';
export 'src/flutter/animated/animated_container.dart';
export 'src/flutter/animated/animated_height.dart';
export 'src/flutter/animated/animator.dart';
export 'src/flutter/appbar.dart';
export 'src/flutter/badge.dart';
export 'src/flutter/bottom_sheet.dart';
export 'src/flutter/card.dart';
export 'src/flutter/center.dart';
export 'src/flutter/clippers/vx_arc.dart';
export 'src/flutter/clippers/vx_diagonal.dart';
export 'src/flutter/clippers/vx_half.dart';
export 'src/flutter/common/velocity_conditional.dart';
export 'src/flutter/common/velocity_curve.dart';
export 'src/flutter/common/velocity_ensure_visible.dart';
export 'src/flutter/common/velocity_responsive.dart';
export 'src/flutter/common/velocity_two.dart';
export 'src/flutter/common/velocity_zero.dart';
export 'src/flutter/container.dart';
export 'src/flutter/dash.dart';
export 'src/flutter/dialog.dart';
export 'src/flutter/divider.dart';
export 'src/flutter/drawer.dart';
export 'src/flutter/drop_down_button.dart';
export 'src/flutter/flex.dart';
export 'src/flutter/gesture.dart';
export 'src/flutter/icon.dart';
export 'src/flutter/list.dart';
export 'src/flutter/marquee.dart';
export 'src/flutter/object.dart';
export 'src/flutter/opacity.dart';
export 'src/flutter/padding.dart';
export 'src/flutter/pinview.dart';
export 'src/flutter/platforms.dart';
export 'src/flutter/popup_menu.dart';
export 'src/flutter/preview.dart';
export 'src/flutter/random.dart';
export 'src/flutter/rating.dart';
export 'src/flutter/rich_text.dart';
export 'src/flutter/routes.dart';
export 'src/flutter/scroll.dart';
export 'src/flutter/selectable_text.dart';
export 'src/flutter/shapes.dart';
export 'src/flutter/shift.dart';
export 'src/flutter/shimmer.dart';
export 'src/flutter/sizedbox.dart';
export 'src/flutter/skeleton.dart';
export 'src/flutter/stepper.dart';
export 'src/flutter/swiper.dart';
export 'src/flutter/text.dart';
export 'src/flutter/textfield.dart';
export 'src/flutter/theme.dart';
export 'src/flutter/timeline/timeline_widget.dart';
export 'src/flutter/toast.dart';
export 'src/flutter/transform.dart';
export 'src/flutter/widgets.dart';
export 'src/nav/vx_delegate.dart';
export 'src/nav/vx_information_parser.dart';
export 'src/nav/vx_nav_config.dart';
export 'src/nav/vx_observer.dart';
export 'src/nav/vx_route_page.dart';
export 'src/responsive_ui.dart';
export 'src/velocity_xx.dart';

==> velocity_x-3.3.0.tar.gz: lib/velocity_x.dart <==
library velocity_x;

export 'package:vxstate/vxstate.dart';

export 'src/dart/guard.dart';
export 'src/dart/timeline.dart';
export 'src/extensions/bool_ext.dart';
export 'src/extensions/context_ext.dart';
export 'src/extensions/date_time_ext.dart';
export 'src/extensions/iterable_ext.dart';
export 'src/extensions/list_ext.dart';
export 'src/extensions/num_ext.dart';
export 'src/extensions/string_ext.dart';
export 'src/flutter/animated/animated_container.dart';
export 'src/flutter/animated/animated_height.dart';
export 'src/flutter/appbar.dart';
export 'src/flutter/badge.dart';
export 'src/flutter/bottom_sheet.dart';
export 'src/flutter/card.dart';
export 'src/flutter/center.dart';
export 'src/flutter/clippers/vx_arc.dart';
export 'src/flutter/clippers/vx_diagonal.dart';
export 'src/flutter/clippers/vx_half.dart';
export 'src/flutter/common/velocity_conditional.dart';
export 'src/flutter/common/velocity_curve.dart';
export 'src/flutter/common/velocity_ensure_visible.dart';
export 'src/flutter/common/velocity_responsive.dart';
export 'src/flutter/common/velocity_two.dart';
export 'src/flutter/common/velocity_zero.dart';
export 'src/flutter/container.dart';
export 'src/flutter/dash.dart';
export 'src/flutter/dialog.dart';
export 'src/flutter/divider.dart';
export 'src/flutter/drawer.dart';
export 'src/flutter/drop_down_button.dart';
export 'src/flutter/flex.dart';
export 'src/flutter/gesture.dart';
export 'src/flutter/glass.dart';
export 'src/flutter/icon.dart';
export 'src/flutter/list.dart';
export 'src/flutter/marquee.dart';
export 'src/flutter/object.dart';
export 'src/flutter/opacity.dart';
export 'src/flutter/padding.dart';
export 'src/flutter/pinview.dart';
export 'src/flutter/platforms.dart';
export 'src/flutter/popup_menu.dart';
export 'src/flutter/preview.dart';
export 'src/flutter/random.dart';
export 'src/flutter/rating.dart';
export 'src/flutter/rich_text.dart';
export 'src/flutter/routes.dart';
export 'src/flutter/scroll.dart';
export 'src/flutter/selectable_text.dart';
export 'src/flutter/shapes.dart';
export 'src/flutter/shift.dart';
export 'src/flutter/shimmer.dart';
export 'src/flutter/sizedbox.dart';
export 'src/flutter/skeleton.dart';
export 'src/flutter/stepper.dart';
export 'src/flutter/swiper.dart';
export 'src/flutter/table.dart';
export 'src/flutter/text.dart';
export 'src/flutter/textfield.dart';
export 'src/flutter/theme.dart';
export 'src/flutter/timeline/timeline_widget.dart';
export 'src/flutter/toast.dart';
export 'src/flutter/transform.dart';
export 'src/flutter/widgets.dart';
export 'src/nav/vx_delegate.dart';
export 'src/nav/vx_information_parser.dart';
export 'src/nav/vx_nav_config.dart';
export 'src/nav/vx_observer.dart';
export 'src/nav/vx_route_page.dart';
export 'src/responsive_ui.dart';
export 'src/velocity_xx.dart';
